ControllerWidgetInflater class

Inheritance

Constructors

ControllerWidgetInflater()

Properties

hashCode int
The hash code for this object.
no setterinherited
inflatesCustomWidget bool
Whether special private objects are added to the attribute map passed to the inflate method
no setteroverride
inflatesOwnChildren bool
Whether the class is responsible for calling XWidget.inflateXmlElementChildren to build its children.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The XML element name for the inflater.
no setteroverride

Methods

inflate(Map<String, dynamic> attributes, List children, List<String> text) ControllerWidget?
Inflates an xml element into a flutter object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseAttribute(String name, String value) → dynamic
Parses an XML attribute into a constructor argument
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited