InflaterDef class

A class annotation for custom widget inflaters.

Use this class annotation to configure inflaters for custom widgets and helpers.

@InflaterDef(inflaterType: 'MyTitle', inflatesOwnChildren: true)
class MyTitleWidget {
...
}

Create a null const variable in your inflater spec Dart file.

const MyTitleWidget? _myTitleWidget = null;

Constructors

InflaterDef({String? inflaterType, required bool inflatesOwnChildren})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inflaterType String?
The XML element name for the inflater.
final
inflatesOwnChildren bool
Whether the class is responsible for calling XWidget.inflateXmlElementChildren to build its children.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited