Tag class abstract
The base class for all tags.
All tags must implement this class and then register themselves using `XWidget.registerTag(...);
Constructors
- Tag()
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processTag(
XmlElement element, Map< String, dynamic> attributes, Dependencies dependencies) → Children? - Executes the tag's implementation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited