TargetUri class

Constructors

TargetUri.parse(String target)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hasQuery bool
no setter
path String
final
query String
no setter
queryParameters Map<String, String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildTargetPath(String destinationPath, [_RoutePattern? matchedPattern]) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited