Children class
Constructors
- Children()
Properties
-
attributes
→ Map<
String, dynamic> -
Holds all parsed attributes
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- objects → List
-
Holds all inflated classes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
text
→ List<
String> -
Holds all parsed lines of text
final
Methods
-
addAll(
Children? children) → void -
getWidgets(
) → List< Widget> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited