Dependencies class
Constructors
-
Dependencies([Map<
String, dynamic> ? data])
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addAll(
Map< String, dynamic> data) → Dependencies -
Adds all key/value dependency pairs of
datato this instance. -
copy(
{Map< String, dynamic> ? addData, List<String> ? preserveData}) → Dependencies - Creates a shallow copy.
-
getValue(
String path) → dynamic -
Returns the dependency referenced by
pathor null. -
listenForChanges(
String path, [dynamic initialValue, dynamic defaultValue]) → ValueNotifier -
Creates or returns the existing ValueNotifier for the dependency
referenced by
path. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putIfAbsent(
String key, dynamic value) → void -
Adds the
valueas a dependency for the specifiedkeyif it doesn't already exist. -
removeValue(
String key) → dynamic -
Removes the dependency referenced by
key. -
setValue(
String path, dynamic value) → void -
Adds or replaces a dependency referenced by
path. -
toString(
) → String -
Returns a formatted JSON string representation of this instance.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String key) → dynamic -
Returns the dependency references by
keyor null. -
operator []=(
String key, dynamic value) → void -
Adds or replaces a dependency referenced by
key.