FragmentResourceBundle class
- Inheritance
-
- Object
- ResourceBundle
- FragmentResourceBundle
Constructors
- FragmentResourceBundle(String pathSegment)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pathSegment → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearFragmentCache(
) → void - Clears the parsed XML cache. Safe to call when caching is disabled.
-
getFragment(
String fqn) → XmlDocument -
Returns the parsed
XmlDocumentfor the given fully-qualified fragment name. Uses the internal cache when enabled. -
getFragmentFqn(
String name, [String? relativeTo]) → String -
getFragmentRaw(
String fqn) → String - Returns the raw XML string for the given fully-qualified name.
-
loadFromAssetBundle(
String fileName, String resPath, String resName, String resExt, AssetBundle assetBundle) → Future< void> -
override
-
loadFromString(
String resPath, String resName, String resExt, String content) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateFragment(
String fqn, String content) → void - Updates a single fragment's raw XML content by fully-qualified name.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited