Resources class
- Available extensions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addResourceBundles(
List< ResourceBundle> bundles) → void - Registers custom ResourceBundle instances for use with Resources.of.
-
getBool(
String name) → bool -
Available on Resources, provided by the ValueResourceExt extension
-
getColor(
String name) → Color -
Available on Resources, provided by the ValueResourceExt extension
-
getColorString(
String name) → String -
Available on Resources, provided by the ValueResourceExt extension
-
getDouble(
String name) → double -
Available on Resources, provided by the ValueResourceExt extension
-
getFragment(
String fqn) → String -
Available on Resources, provided by the FragmentResourcesExt extension
-
getFragmentFqn(
String name, [String? relativeTo]) → String -
Available on Resources, provided by the FragmentResourcesExt extension
-
getInt(
String name) → int -
Available on Resources, provided by the ValueResourceExt extension
-
getString(
String name) → String -
Available on Resources, provided by the ValueResourceExt extension
-
loadResources(
{String? fragmentsPath, String? valuesPath, String? projectKey, String? storageKey, String? channel, String? version, Duration? downloadTimeout, AssetBundle? assetBundle}) → Future< void> - Loads resources from local assets or from the XWidget Cloud content server.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replaceResourceBundles(
List< ResourceBundle> bundles) → void - Registers ResourceBundle instances, replacing any existing bundles that conflict by type or path segment.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of<
T extends ResourceBundle> () → T