XWidget class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
clearXmlCache()
→ void
-
Clear fragment XML cache
-
createController(String name)
→ Controller
-
-
dump(XmlElement element, Dependencies dependencies)
→ String
-
-
getFragment(String name)
→ Fragment
-
-
getIcon(String name)
→ IconData?
-
-
inflateFragment<T>(String fragmentName, Dependencies dependencies, {Iterable<XmlAttribute>? inheritedAttributes, Map<String, dynamic>? params})
→ T?
-
Inflates an XML fragment by name and returns the resulting widget tree.
-
inflateFromXmlElement<T>(XmlElement element, Dependencies dependencies, {Iterable<XmlAttribute>? inheritedAttributes})
→ T?
-
Inflates a single XML element into its corresponding Dart object.
-
inflateXmlElementChildren(XmlElement element, Dependencies dependencies, {Set<String>? excludeElements, bool excludeText = false, dynamic excludeAttributes = false, dynamic onlyAttributes = false})
→ Children
-
Inflates the children of an XML element and collects the results.
-
initialize({String? fragmentsPath, String? valuesPath, String? projectKey, String? storageKey, String? channel, String? version, Duration? downloadTimeout, AssetBundle? assetBundle, Level logLevel = Level.INFO})
→ Future<void>
-
Initializes the XWidget framework.
-
mergeXmlAttributes(Iterable<XmlAttribute> list1, Iterable<XmlAttribute>? list2)
→ Iterable<XmlAttribute>
-
-
parseAllExpressions(String input, Dependencies dependencies)
→ String
-
-
parseAttribute({required String attributeName, required String? attributeValue, required Dependencies dependencies, Inflater? inflater})
→ dynamic
-
-
parseExpression(String expression, Dependencies dependencies)
→ dynamic
-
-
parseXmlAttributes(XmlElement element, Dependencies dependencies, {Inflater? inflater, Iterable<XmlAttribute>? inheritedAttributes})
→ Map<String, dynamic>
-
-
pushFragment(BuildContext context, String fragmentName, Dependencies dependencies, {String? pageName, Map<String, dynamic>? params, bool cupertinoStyle = false})
→ void
-
Pushes a new route onto the navigator by inflating an XML fragment.
-
registerControllerFactory<T extends Controller>(XWidgetControllerFactory<T> factory)
→ void
-
-
registerControllerFactoryForName(String name, XWidgetControllerFactory<Controller> factory)
→ void
-
-
registerIcon(String name, IconData iconData)
→ void
-
-
registerInflater(Inflater inflater)
→ void
-
-
registerModel<T extends Model>(ModelFactory<T> factory, [List<PropertyTransformer>? transformers])
→ void
-
-
registerTag(Tag tag)
→ void
-
-
registerTypeConverter<T>(TypeConverter<T> function)
→ void
-
-
scopeDependencies(XmlElement element, Dependencies dependencies, String? scope, [String defaultScope = "inherit"])
→ Dependencies
-
-
shouldInflateXmlElement(XmlElement element, {Set<String>? excludeElements, bool excludeAttributes = false, bool onlyAttributes = false})
→ bool
-